cmoncrawl.common.types.ExtractConfig — CmonCrawl 1.0.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# cmoncrawl.common.types.ExtractConfig

class cmoncrawl.common.types.ExtractConfig(extractors_path: Path, routes: List[RoutesConfig])

  Configuration for run.

  __init__(extractors_path: Path, routes: List[RoutesConfig]) → None

  Methods

  `__init__`(extractors_path, routes) |
  `from_dict`(kvs, *[, infer_missing]) |
  `from_json`(s, *[, parse_float, parse_int, ...]) |
  `schema`(*[, infer_missing, only, exclude, ...]) |
  `to_dict`([encode_json]) |
  `to_json`(*[, skipkeys, ensure_ascii, ...]) |

  Attributes

  `extractors_path` |
  `routes` |